@@ -4,6 +4,7 @@ chain_name=aembit-redirect-chain
 aembit_group_id=$(id --group aembit_agent_proxy)
 agent_proxy_port=38080
 agent_dns_port=8053
+container_cidr=$AEMBIT_DOCKER_CONTAINER_CIDR
 
 update-alternatives --set iptables /usr/sbin/iptables-legacy
 update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
@@ -11,7 +12,7 @@ update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
 iptables -t raw -D OUTPUT -p udp --dport 53 -m owner --gid-owner "${aembit_group_id}" -j NOTRACK
 
 # Ignore (return to the main chain) all packets from our agent proxy
-iptables -t nat -D "${chain_name}" -m owner --gid-owner "${aembit_group_id}" -j RETURN
+iptables -t nat -D "${chain_name}" -m owner --uid-owner "${aembit_group_id}" -j RETURN
 
 # Ignore TCP loopback
 iptables -t nat -D "${chain_name}" -p tcp -o lo -j RETURN
@@ -28,3 +29,8 @@ iptables -t nat -D OUTPUT -j "${chain_name}"
 
 # Delete custom chain
 iptables  -t nat -X "${chain_name}"
+
+# Delete NAT prerouting rule if the customer specified a container CIDR
+if [ -n $container_cidr ]; then
+    iptables -t nat -D PREROUTING -p tcp -s $container_cidr -j REDIRECT --to-port $agent_proxy_port
+fi
