@@ -4,6 +4,7 @@ chain_name=aembit-redirect-chain
 aembit_group_id=$(id --group aembit_agent_proxy)
 agent_proxy_port=38080
 agent_dns_port=8053
+container_cidr=$AEMBIT_DOCKER_CONTAINER_CIDR
 
 update-alternatives --set iptables /usr/sbin/iptables-legacy
 update-alternatives --set ip6tables /usr/sbin/ip6tables-legacy
@@ -55,3 +56,8 @@ iptables -t nat -A "${chain_name}" -p udp --dport 53 -j REDIRECT --to "${agent_d
 
 # Add out chain 
 iptables -t nat -A OUTPUT -j "${chain_name}"
+
+# If we know the containers' CIDR block, preroute container traffic through agent proxy
+if [ -n $container_cidr ]; then
+    iptables -t nat -A PREROUTING -p tcp -s $container_cidr -j REDIRECT --to-port $agent_proxy_port
+fi
